PostProcess

Enum PostProcess 

pub enum PostProcess {
    None,
    ReplaceMarkers,
    ReplaceMarkersAndDocBlocks,
}
Post format processing options - optionally replace comment/blank markers and doc blocks

Variants



None

No post processing after formatting (default)



ReplaceMarkers

Available on crate feature post_process only.

Replace _blank_! and _comment_! markers



ReplaceMarkersAndDocBlocks

Available on crate feature post_process only.

Replace _blank_! and _comment_! markers and #[doc = ""] (with ///)

Implementations

Source

impl PostProcess

pub fn replace_markers(self) -> bool

Returns true if blank and comment markers should be replaced in the formatted source or false if they should not be

pub fn replace_doc_blocks(self) -> bool

Available on crate feature post_process only.

Returns true if doc blocks should be replaced in the formatted source or false if they should not be